@@ -10,29 +10,31 @@ LINK_TO_ALL_OBJECTS = 0      # link to non-wiki page objects ? unimplemented
 AUTO_UPGRADE = 1             # upgrade old pages when viewed
 LARGE_FILE_SIZE = 1024*1024  # images larger than this will not be inlined
 LEAVE_PLACEHOLDER = 0        # leave a placeholder page when renaming ?
-SCROLL_CONTENTS = 0          # scroll to current page in contents (=>many urls)
+SHOW_CURRENT_PAGE_IN_CONTENTS = 1 # scroll in contents (=> more robot urls)
+DEFAULT_DISPLAYMODE = 'minimal'   # default display mode for the standard skin
 
 PAGE_METATYPE =      'ZWiki Page' # meta_type of ZWikiPage objects
 PAGE_PORTALTYPE =    'Wiki Page'  # content type used in CMF/Plone
 WIKI_ADD_MENU_NAME = 'ZWiki'      # items in ZMI add menu.. 
 PAGE_ADD_MENU_NAME = 'ZWiki Page' # (this one must match PAGE_METATYPE)
 
+# XXX clean this up somehow, as Bob suggests
 # the page types we'll offer in the default edit form,
 # unless overridden by an allowed_page_types property.
-# These must match the ids in PageTypes.py.
+# These must match the ids in pagetypes
 ALLOWED_PAGE_TYPES = [
-    'msgstxprelinkdtmlfitissuehtml',
-    'msgrstprelinkfitissue',
-    'msgwwmlprelinkfitissue',
-    'dtmlhtml',
+    'stx',
+    'rst',
+    'wwml',
+    'html',
     'plaintext',
     ]
 # ditto for wikis in CMF/Plone
 ALLOWED_PAGE_TYPES_IN_PLONE = [
-    'msgstxprelinkdtmlfitissuehtml',
-    'msgrstprelinkfitissue',
-    #'msgwwmlprelinkfitissue',
-    'dtmlhtml',
+    'stx',
+    'rst',
+    #'wwml',
+    'html',
     'plaintext',
     ]
 
@@ -84,9 +86,10 @@ PAGE_METADATA = [
     'last_edit_time',
     'last_editor',   
     'last_log',
-    'links',
+    #'links', # XXX problems for epoz/plone, not needed ?
     'page_type',     
     'parents',
+    'rating',
     'severity',
     'severity_index',
     'size',
@@ -94,13 +97,7 @@ PAGE_METADATA = [
     'status_index',
     'subscriber_list',
     'summary',
+    'voteCount',
     ]
 
-# for reStructuredText:
-# You can customize the default encoding by creating a file
-# sitecustomize.py somewhere in yout PYTHONPATH:
-#  import sys
-#  sys.setdefaultencoding("iso-8859-1")
-#import sys
-#sys.setdefaultencoding("iso-8859-1")
-#hmm not right
+IDS_TO_AVOID = ['RESPONSE','REQUEST','Epoz','epoz']
