@@ -8,7 +8,7 @@ from urllib import quote, unquote
 
 from AccessControl import getSecurityManager, ClassSecurityInfo
 from App.Common import absattr
-import Globals
+from Globals import InitializeClass
 from OFS.SimpleItem import SimpleItem
 import zLOG # LOG,ERROR,INFO,WARNING,BLATHER,DEBUG
 from DateTime import DateTime
@@ -25,9 +25,10 @@ except:
     ZOPEVERSION = (9,9,9) # (cvs)
 
 from Products.ZWiki import __version__
-from Defaults import PREFER_USERNAME_COOKIE, PAGE_METADATA, SCROLL_CONTENTS
+from Defaults import PREFER_USERNAME_COOKIE, PAGE_METADATA, \
+     SHOW_CURRENT_PAGE_IN_CONTENTS
 import Permissions
-from LocalizerSupport import _, N_
+from I18nSupport import _
 
 
 class Utils:
@@ -59,11 +60,20 @@ class Utils:
         strings = filter(lambda x:type(x)==type(''), strings)
         return len(join(strings,''))
 
-    def summary(self,size=100):
+    def summary(self,size=100,paragraphs=1):
         """
         Give a short summary of this page's content.
+
+        Take the first N paragraphs of the document part; cut to size
+        characters & replace the last word with ellipsis if necessary.
         """
-        return html_quote(self.text()[:size])
+        size, paragraphs = int(size), int(paragraphs)
+        t = self.documentPart()
+        if paragraphs: t = join(split(t,'\n\n')[:paragraphs],'\n\n')
+        if len(t) > size:
+            t = t[:size]
+            t = re.sub(r'\w*$',r'',t) + '...'
+        return html_quote(t)
 
     security.declareProtected(Permissions.View, 'excerptAt')
     def excerptAt(self, expr, size=100, highlight=1):
@@ -117,8 +127,41 @@ class Utils:
             def getObject(self): return self._obj
         brain = PageBrain(page)
         for attr in PAGE_METADATA+['page_url','title_or_id']:
-            setattr(brain,attr,absattr(getattr(page,attr,None)))
-            #setattr(brain,attr+'__roles__',None) # not needed ?
+            # don't acquire these properties
+            # XXX messy.. aq_base won't be present in tests
+            # XXX temp protection for unpickler import error when page
+            # type class is missing
+            try:
+                setattr(brain, attr,
+                        absattr(getattr(getattr(page,'aq_base',page),attr,None)))
+                #setattr(brain,attr+'__roles__',None) # not needed ?
+            except ImportError:
+                setattr(brain, attr, None)
+                # didn't work
+                #Traceback (most recent call last):
+                #    File "/usr/local/src/Zope-2.7.1-b2/lib/python/ZPublisher/Publish.py", line 101, in publish
+                #        request, bind=1)
+                #    File "/usr/local/src/Zope-2.7.1-b2/lib/python/ZPublisher/mapply.py", line 88, in mapply
+                #        if debug is not None: return debug(object,args,context)
+                #    File "/usr/local/src/Zope-2.7.1-b2/lib/python/ZPublisher/Publish.py", line 39, in call_object
+                #        result=apply(object,args) # Type s<cr> to step into published object.
+                #    File "/zope1/Products/ZWiki/UI.py", line 415, in recentchanges
+                #        return form(self,REQUEST,body=dtmlpart(self,REQUEST))
+                #    File "/usr/local/src/Zope-2.7.1-b2/lib/python/App/special_dtml.py", line 62, in __call__
+                #        (self,)+args[1:],kw)
+                #    File "/usr/local/src/Zope-2.7.1-b2/lib/python/DocumentTemplate/DT_String.py", line 474, in __call__
+                #        try: result = render_blocks(self._v_blocks, md)
+                #    File "/usr/local/src/Zope-2.7.1-b2/lib/python/DocumentTemplate/DT_Let.py", line 76, in render
+                #        return render_blocks(self.section, md)
+                #    File "/usr/local/src/Zope-2.7.1-b2/lib/python/DocumentTemplate/DT_In.py", line 703, in renderwob
+                #        try: append(render(section, md))
+                #    File "/usr/local/src/Zope-2.7.1-b2/lib/python/DocumentTemplate/DT_Try.py", line 140, in render
+                #        return self.render_try_except(md)
+                #    File "/usr/local/src/Zope-2.7.1-b2/lib/python/DocumentTemplate/DT_Try.py", line 174, in render_try_except
+                #        return render_blocks(handler, md)
+                #    File "/usr/local/src/Zope-2.7.1-b2/lib/python/DocumentTemplate/DT_Var.py", line 280, in render
+                #        val = fmt % val
+                #TypeError: not all arguments converted during string formatting
         brain.linkTitle = '' #XXX not using now.. leave blank so tests pass
         return brain
 
@@ -128,11 +171,19 @@ class Utils:
 
         This should only happen with catalog brains, where the catalog does not
         have all the metadata Zwiki expects. We can't add fields to catalog brains,
-        so we'll return a PageBrain instead.
+        so in that case we'll return a PageBrain instead.
+
+        If the catalog says eg page id is None, we don't do anything about that;
+        we'll return it in the metadata.
+
+        If getObject() returns None (a stale catalog entry), we return None.
         """
         for attr in PAGE_METADATA:
             if not hasattr(brain,attr):
-                return self.metadataFor(brain.getObject())
+                # incomplete brain - make a PageBrain
+                p = brain.getObject()
+                if p: return self.metadataFor(p)
+                else: return None
         return brain
 
     security.declareProtected(Permissions.View, 'isZwikiPage')
@@ -165,15 +216,16 @@ class Utils:
         return unquote(text)
 
     security.declareProtected(Permissions.View, 'usernameFrom')
-    def usernameFrom(self, REQUEST=None):
+    def usernameFrom(self, REQUEST=None, ip_address=1):
         """
         Get the best available user id from the current visitor's REQUEST.
 
         We use the first of:
         - a MAILIN_USERNAME set by mailin.py
+        #- an authenticated CMF user's fullname property #XXX check old code
         - an authenticated username
         - a zwiki_username cookie
-        - the client's IP address
+        - the client's IP address, unless disabled
 
         Or, if PREFER_USERNAME_COOKIE in Defaults.py is true, we'll let
         the cookie take precedence. This means an authenticated user could
@@ -195,7 +247,7 @@ class Utils:
                 authenticated_name = None
         cookie_name = REQUEST.cookies.get('zwiki_username',None)
         mailin_name = REQUEST.get('MAILIN_USERNAME',None)
-        ip_addr = REQUEST.REMOTE_ADDR
+        ip_addr = ip_address and REQUEST.REMOTE_ADDR or ''
         if PREFER_USERNAME_COOKIE:
             return mailin_name or cookie_name or authenticated_name or ip_addr
         else:
@@ -230,18 +282,18 @@ class Utils:
 
     def defaultPageUrl(self):
         p = self.defaultPage()
-        return (p and p.pageUrl()) or None
+        return (p and p.pageUrl()) or ''
 
     def urlForDtmlPageOrMethod(self,pagename,methodname):
         """
-        Return the url of an existing dtml page, or of a method, or None.
+        Return the url of an existing dtml page, or of a method, or ''.
         """
         p = self.pageWithName(pagename)
         if p and p.dtmlAllowed() and p.hasDynamicContent(): return p.pageUrl()
         elif methodname: return self.defaultPage().pageUrl()+'/'+methodname
-        else: return None
+        else: return ''
 
-    def urlForPageOrDefault(self,pagename,default=None):
+    def urlForPageOrDefault(self,pagename,default=''):
         """
         Return the url of an existing page, or the default.
         """
@@ -270,7 +322,7 @@ class Utils:
         out from under you anyhow. Try without it for a bit.
         
         """
-        if SCROLL_CONTENTS:
+        if SHOW_CURRENT_PAGE_IN_CONTENTS:
             quotedname = quote(self.pageName())
             if self.pageWithId('SiteMap'): 
                 return '%s/SiteMap?here=%s#%s' \
@@ -279,7 +331,7 @@ class Utils:
                 return '%s/contents#%s' % (self.page_url(),quotedname)
         else:
             if self.pageWithId('SiteMap'): return self.wikiUrl() + '/SiteMap'
-            else: return self.pageUrl() + '/contents'
+            else: return self.defaultPageUrl() + '/contents'
 
     security.declareProtected(Permissions.View, 'changesUrl')
     def changesUrl(self):
@@ -288,7 +340,7 @@ class Utils:
     security.declareProtected(Permissions.View, 'discussionUrl')
     def discussionUrl(self):
         p = self.pageWithName('GeneralDiscussion')
-        return (p and p.pageUrl()) or None
+        return (p and p.pageUrl()) or ''
 
     security.declareProtected(Permissions.View, 'trackerUrl')
     def trackerUrl(self):
@@ -300,11 +352,11 @@ class Utils:
 
     security.declareProtected(Permissions.View, 'indexUrl')
     def indexUrl(self):
-        return self.urlForDtmlPageOrMethod('AllPages',None) #'allpages')
+        return self.urlForDtmlPageOrMethod('AllPages','') #'allpages')
 
     security.declareProtected(Permissions.View, 'uploadsUrl')
     def uploadsUrl(self):
-        return None #self.urlForDtmlPageOrMethod('UploadsPage','uploads')
+        return '' #self.urlForDtmlPageOrMethod('UploadsPage','uploads')
 
     security.declareProtected(Permissions.View, 'preferencesUrl')
     def preferencesUrl(self):
@@ -312,7 +364,7 @@ class Utils:
 
     security.declareProtected(Permissions.View, 'helpUrl')
     def helpUrl(self):
-        return self.urlForPageOrDefault('HelpPage',None)
+        return self.urlForPageOrDefault('HelpPage','')
 
     security.declareProtected(Permissions.View, 'searchUrl')
     def searchUrl(self):
@@ -403,23 +455,39 @@ class Utils:
         minutes=int(math.floor((elapsed-days-hourfactor*hours)/minutefactor))
         seconds=int(round((
             elapsed-days-hourfactor*hours-minutefactor*minutes)/secondsfactor))
+  
+        datepattern = ("%(nb)d %(period)s")
+       
         if years:
-            s = "%d year%s" % (years, years > 1 and 's' or '')
+            s = datepattern % {"nb": years, "period": years > 1 and _('years') or _('year')}
         elif months:
-            s = "%d month%s" % (months, months > 1 and 's' or '')
+            s = datepattern % {"nb":months, "period":months > 1 and _('months') or _('month')}
         elif weeks:
-            s = "%d week%s" % (weeks, weeks > 1 and 's' or '')
+            s = datepattern % {"nb":weeks, "period":weeks > 1 and _('weeks') or _('week')}
         elif days:
-            s = "%d day%s" % (days, days > 1 and 's' or '')
+            s = datepattern % {"nb":days, "period": days > 1 and _('days') or _('day') }
         elif hours:
-            s = "%d hour%s" % (hours, hours > 1 and 's' or '')
+            s = datepattern % {"nb":hours, "period":hours > 1 and _('hours') or _('hour')}
         elif minutes:
-            s = "%d minute%s" % (minutes, minutes > 1 and 's' or '')
+            s = datepattern % {"nb":minutes, "period":minutes > 1 and _('minutes') or _('minute')}
         else:
-            s = "%d second%s" % (seconds, seconds > 1 and 's' or '')
+            s = datepattern % {"nb":seconds, "period":seconds > 1 and _('seconds') or _('second')}
+            
         return s
 
-Globals.InitializeClass(Utils)
+    security.declareProtected(Permissions.View,'include')
+    def include(self,page,REQUEST=None):
+        """
+        Convenience method for including the body of one page within another.
+
+        Renders without the skin, passes REQUEST in case authentication is
+        needed, fails silently if page does not exist.
+        """
+        p = self.pageWithNameOrId(page)
+        if p: return p(bare=1,REQUEST=REQUEST)
+        else: return ''
+        
+InitializeClass(Utils)
 
 
 # generic utilities
@@ -621,3 +689,30 @@ class Popen3:
             self.err=open(errfile,"r").read()
             os.remove(errfile)
 
+def stripList(lines):
+    """
+    Strip whitespace elements from a list of strings, such as a lines property.
+
+    Accept a list or tuple, return a list. (Zope 2.7 props are tuples.)
+    """
+    return filter(lambda x:x.strip(),list(lines))
+
+def isIpAddress(s):
+    """
+    True if s looks like an IP address.
+    """
+    return re.match(r'[0-9\.\s]*$',s) and 1
+
+def isEmailAddress(s):
+    """
+    True if s looks like an email address.
+    """
+    if s and '@' in s: return 1
+    else: return 0
+
+def isUsername(s):
+    """
+    True if s looks like a username (for Mail.py's purposes).
+    """
+    return not isEmailAddress(s)
+
