@@ -54,11 +54,11 @@ from types import *
 from AccessControl import getSecurityManager, ClassSecurityInfo
 from App.Common import rfc1123_date
 from DateTime import DateTime
-import Globals
+from Globals import InitializeClass
 from OFS.DTMLDocument import DTMLDocument
 
 import Permissions
-from Defaults import AUTO_UPGRADE, \
+from Defaults import AUTO_UPGRADE, IDS_TO_AVOID, \
      PAGE_METATYPE, LINK_TO_ALL_CATALOGED, LINK_TO_ALL_OBJECTS
 from Regexps import url, bracketedexpr, doublebracketedexpr, \
      wikiname, wikilink, interwikilink, remotewikiurl, \
@@ -68,40 +68,19 @@ from Regexps import url, bracketedexpr, doublebracketedexpr, \
 from Utils import Utils, BLATHER
 from UI import UI
 from OutlineSupport import OutlineSupport
+from Rating import RatingSupport
 from Diff import DiffSupport
-from Mail import MailSupport
+from Mail import SubscriberManagerMixin, MailSupport
 from CatalogAwareness import CatalogAwareness
 from Tracker import TrackerSupport
-from Regulations import RegulationsSupport
 from CMF import CMFAwareness
 from Fit import FitSupport
-from Messages import MessagesSupport
+from Comments import CommentsSupport
 from PurpleNumbers import PurpleNumbersSupport
 from Admin import AdminSupport
 from Editing import EditingSupport
-from LocalizerSupport import LocalDTMLFile, _, N_
-DTMLFile = LocalDTMLFile
-del LocalDTMLFile
-
-# these seem to need to be in this module or zope complains couldn't load state
-#from PageTypes import MIDSECTIONMARKER,PAGETYPES,PAGE_TYPES
-from PageTypes import MIDSECTIONMARKER, \
-    ZwikiStxPageType, \
-    ZwikiRstPageType, \
-    ZwikiWwmlPageType, \
-    ZwikiHtmlPageType, \
-    ZwikiPlaintextPageType
-PAGETYPES = [
-    ZwikiStxPageType,
-    ZwikiRstPageType,
-    ZwikiWwmlPageType,
-    ZwikiHtmlPageType,
-    ZwikiPlaintextPageType,
-    ]
-# a dictionary of ids and names used by legacy skin templates
-PAGE_TYPES = {}
-for t in PAGETYPES: PAGE_TYPES[t._id]=t._name
-
+from I18nSupport import DTMLFile, _
+from pagetypes import MIDSECTIONMARKER, PAGETYPES, PAGE_TYPES, ZwikiStxPageType
 
 
 class ZWikiPage(
@@ -111,13 +90,14 @@ class ZWikiPage(
     OutlineSupport,
     DiffSupport,
     MailSupport,
+    SubscriberManagerMixin,
     CatalogAwareness,
     TrackerSupport,
-    RegulationsSupport,
     CMFAwareness,
     FitSupport,
-    MessagesSupport,
+    CommentsSupport,
     PurpleNumbersSupport,
+    RatingSupport,
     AdminSupport,
     Utils,
     ):
@@ -125,20 +105,20 @@ class ZWikiPage(
     A ZWikiPage is essentially a DTML Document which knows how to render
     itself in various wiki styles, and can function inside or outside a
     CMF site. A lot of extra methods are provided to support
-    wiki-building, email, issue tracking, etc.
-
-    Mixins are used to organize functionality into distinct modules.
-    Initialization, rendering, editing and miscellaneous methods remain in
-    the base class.
-
+    wiki-building, email, issue tracking, etc.  Mixins are used to
+    organize functionality into modules.
     """
     security = ClassSecurityInfo()
     security.declareObjectProtected('View')
     security.declareProtected(Permissions.Edit, 'manage_upload')
     security.declareProtected(Permissions.FTP, 'manage_FTPstat') # needed
     security.declareProtected(Permissions.FTP, 'manage_FTPlist') # ?
+    # perms need at least one declaration (in this file ?) to be recognized
+    # this is dumb indeed.. need tests to figure out the rules of this game
     security.declareProtected(Permissions.ChangeType, 'dummy')
-    def dummy(self): pass # make sure that declaration is seen
+    def dummy(self): pass
+    security.declareProtected(Permissions.Reparent, 'dummy2')
+    def dummy2(self): pass
     def checkPermission(self, permission, object):
         return getSecurityManager().checkPermission(permission,object)
 
@@ -161,7 +141,7 @@ class ZWikiPage(
         {'id':'last_log', 'type': 'string', 'mode': 'r'},
         ) \
         + OutlineSupport._properties \
-        + MailSupport._properties \
+        + SubscriberManagerMixin._properties \
         + CatalogAwareness._properties
 
     meta_type = PAGE_METATYPE
@@ -180,6 +160,7 @@ class ZWikiPage(
     # behaviour. It will return the old id string when called, which
     # should keep existing catalogs working.
     page_type = PAGETYPES[0]()
+    # XXX page_type's are separate instances - use class or singleton instance ?
     def setPageType(self,id=None): self.page_type = self.lookupPageType(id)()
     def pageType(self):
         # I'd rather keep this in upgrade(), but someone might do
@@ -224,32 +205,31 @@ class ZWikiPage(
                                   )
 
     ######################################################################
-    # rendering (see also the page type objects)
+    # generic rendering code (see also pagetypes/*)
 
     security.declareProtected(Permissions.View, '__call__')
     def __call__(self, client=None, REQUEST={}, RESPONSE=None, **kw):
         """
-        Render this zwiki page, upgrading it on the fly if needed
-
-        Similar situation to __init__
+        Render this zwiki page, also upgrading it on the fly if needed.
         """
         if AUTO_UPGRADE: self.upgrade(REQUEST)
-        if self.supportsCMF() and self.inCMF():
-            return CMFAwareness.__call__(self,client,REQUEST,RESPONSE,**kw)
-        else:
-            rendered = self.render(client,REQUEST,RESPONSE,**kw)
-            if RESPONSE:
-                RESPONSE.setHeader('Content-Type', 'text/html')
-                #RESPONSE.setHeader('Last-Modified', rfc1123_date(self._p_mtime)) 
-                #causes browser caching problems ? 
-            return rendered
+        # why do we need this ?
+        #if self.supportsCMF() and self.inCMF():
+        #    return CMFAwareness.__call__(self,client,REQUEST,RESPONSE,**kw)
+        #else:
+        if RESPONSE:
+            #XXX problem ? this is set by all templates
+            RESPONSE.setHeader('Content-Type', 'text/html') 
+            #RESPONSE.setHeader('Last-Modified', rfc1123_date(self._p_mtime)) 
+            #causes browser caching problems ? 
+        rendered = self.render(client,REQUEST,RESPONSE,**kw)
+        return rendered
 
     def render(self, client=None, REQUEST={}, RESPONSE=None, **kw):
         """
-        Render the body of this zwiki page according to it's page_type
+        Render this zwiki page according to it's page_type.
         """
-        if not self.preRendered():
-            self.setPreRendered(self.pageType().preRender(self))
+        if not self.preRendered(): self.preRender()
         return self.pageType().render(self, REQUEST, RESPONSE, **kw)
 
     def preRender(self,clear_cache=0):
@@ -324,46 +304,61 @@ class ZWikiPage(
         return doc + self.renderMidsection() + discussion
 
     def renderMidsection(self):
-        # XXX too expensive.. we calculate the wiki nesting info twice
-        # per page view, once here and once for the navlinks in the header
         if self.subtopicsEnabled(): return self.subtopics(deep=1)
         else: return ''
     
     security.declareProtected(Permissions.View, 'supportsStx')
-    def supportsStx(self): return self.pageType().supportsStx()
+    def supportsStx(self): 
+        """supportsStx""" 
+        return self.pageType().supportsStx()
 
     security.declareProtected(Permissions.View, 'supportsRst')
-    def supportsRst(self): return self.pageType().supportsRst()
+    def supportsRst(self): 
+        """supportsRst""" 
+        return self.pageType().supportsRst()
 
     security.declareProtected(Permissions.View, 'supportsWwml')
-    def supportsWwml(self): return self.pageType().supportsWwml()
+    def supportsWwml(self): 
+        """supportsWwml""" 
+        return self.pageType().supportsWwml()
 
     security.declareProtected(Permissions.View, 'supportsWikiLinks')
-    def supportsWikiLinks(self): return self.pageType().supportsWikiLinks()
+    def supportsWikiLinks(self): 
+        """supportsWikiLinks"""
+        return self.pageType().supportsWikiLinks()
 
     security.declareProtected(Permissions.View, 'supportsHtml')
-    def supportsHtml(self): return self.pageType().supportsHtml()
+    def supportsHtml(self): 
+        """supportsHtml"""
+        return self.pageType().supportsHtml()
 
     security.declareProtected(Permissions.View, 'supportsDtml')
-    def supportsDtml(self): return self.pageType().supportsDtml()
+    def supportsDtml(self): 
+        """supportsDtml"""
+        return self.pageType().supportsDtml()
 
     security.declareProtected(Permissions.View, 'hasDynamicContent')
     def hasDynamicContent(self):
+        """hasDynamicContent"""
         return (self.supportsDtml() and
                 re.search(r'(?i)(<dtml|&dtml)',self.read()) is not None)
 
     security.declareProtected(Permissions.View, 'dtmlAllowed')
-    def dtmlAllowed(self): return (
-        getattr(self,'allow_dtml',0) and
-        not hasattr(self,'no_dtml')
-        )
+    def dtmlAllowed(self):
+        """Is embedded DTML permitted on this page ?"""
+        return (
+            getattr(self,'allow_dtml',0) and
+            not hasattr(self,'no_dtml')
+            )
 
     security.declareProtected(Permissions.View, 'supportsEpoz')
     def supportsEpoz(self):
+        """Is Epoz editing available for this page ?"""
         return self.epozInstalled() and self.pageType().supportsEpoz()
 
     security.declareProtected(Permissions.View, 'epozInstalled')
     def epozInstalled(self):
+        """Is Epoz installed ?"""
         return hasattr(self,'Epoz')
 
     ######################################################################
@@ -407,7 +402,7 @@ class ZWikiPage(
         make them easy to find again.  Tries to be smart about finding
         links only where you want it to.
         """
-        get_transaction().note('findlinks')
+        #get_transaction().note('findlinks')
         markedtext = ''
         state = {'lastend':0,'inpre':0,'incode':0,'intag':0,'inanchor':0}
         lastpos = 0
@@ -468,6 +463,29 @@ class ZWikiPage(
         """
         return re.sub(wikilink, r'!\1', match.group(1))
 
+    def spacedWikinamesEnabled(self):
+        """Should all wikinames be displayed with spaces in this wiki ?"""
+        return getattr(self.folder(),'spaced_wikinames',0) and 1
+
+    security.declareProtected(Permissions.View, 'formatWikiname')
+    def formatWikiname(self,wikiname):
+        """
+        Convert a wikiname to this wiki's standard display format.
+
+        Ie, leave it be or add ungodly spaces depending on the
+        'spaced_wikinames' property.
+
+        Not used yet, probably a waste of time.
+        """
+        if self.spacedWikinamesEnabled():
+            spaced = wikiname[0]
+            for c in wikiname[1:]:
+                if c in string.uppercase: spaced += ' '
+                spaced += c
+            return spaced
+        else: 
+            return wikiname
+
     def renderLink(self,link,allowed=0,state=None,text='',
                    link_title=None,access_key=None):
         """
@@ -530,7 +548,7 @@ class ZWikiPage(
                 re.match(bracketedexpr,linkorig)): #was processed above
             return link
 
-        # we have a wikiname - does a matching page exist in this wiki ?
+        # we have a wiki link! Does a matching page exist in this wiki ?
         if self.pageWithNameOrId(link):
             # the wikiname might not be the page id if international
             # characters have been enabled in wiki names but not page ids
@@ -553,13 +571,13 @@ class ZWikiPage(
         if (hasattr(self.folder(),'aq_parent') and
               hasattr(self.folder().aq_parent, link) and
               self.isZwikiPage(getattr(self.folder().aq_parent,link))): #XXX poor caching
-            return '<a href="%s/../%s" title="page in parent wiki">../%s</a>'\
-                   % (self.wiki_url(),quote(link),linkorig)
+            return '<a href="%s/../%s" title="%s">../%s</a>'\
+                   % (self.wiki_url(),quote(link),_("page in parent wiki"),linkorig)
 
         # otherwise, provide a creation link
-        return '%s<a class="new" href="%s/%s/editform?page=%s" title="create this page">?</a>' \
+        return ('%s<a class="new" href="%s/%s/createform?page=%s" title="%s">?</a>') \
                % (linkorig, self.wiki_url(), quote(self.id()),
-                  quote(linknobrackets))
+                  quote(linknobrackets), _("create this page"))
 
     def renderInterwikiLink(self, link):
         """
@@ -635,24 +653,34 @@ class ZWikiPage(
         """
         interval = self.asAgeString(last_edit_time)
         if not prettyprint:
-            s = "last edited %s ago" % (interval)
+            s = _("last edited %(interval)s ago") % {"interval":interval}
         else:
             try:
                 #XXX do timezone conversion ?
                 lastlog = self.lastlog()
                 if lastlog: lastlog = ' ('+lastlog+')'
-                s = 'last edited <a href="%s/diff" title="show last edit%s">%s</a> ago' % \
-                    (self.page_url(), lastlog, interval)
+                
+                # build the link around the interval
+                linked_interval = (' <a href="%(page_url)s/diff" title="' % self.page_url() +
+                                   _('show last edit %(lastlog)s') % {"lastlog":lastlog} +
+                                   ">" + interval + "</a>" )
+                
+                # use the link in a clear i18n way                                                                         
+                s =  _('last edited %(interval)s ago')  % {"interval": linked_interval}
+
             except:
-                s = 'last edited %s ago' % (interval)
+                s = _('last edited %(interval)s ago') % {"interval": interval}
+                
         if (last_editor and
             not re.match(r'^[0-9\.\s]*$',last_editor)):
             # escape some things that might cause trouble in an attribute
             editor = re.sub(r'"',r'',last_editor)
+
+            #XXX cleanup
             if not prettyprint:
-                s = s + " by %s" % (editor)
+                s = s + " " + _("by %(editor)s")% {"editor":editor}
             else:
-                s = s + " by <b>%s</b>" % (editor)
+                s = s + " " + _("by %(editor)s") % {"editor":"<b>%s</b>" % editor} 
         return s
     
     def linkToAllCataloged(self):
@@ -672,12 +700,15 @@ class ZWikiPage(
         Return the name of this wiki page.
 
         This is normally in the title attribute, but use title_or_id
-        to handle eg pages created in the ZMI.
+        to handle eg pages created via the ZMI.
         """
         return self.title_or_id()
     
     security.declarePublic('Title')
     def Title(self):
+        """
+        Title
+        """
         return self.pageName()
 
     security.declareProtected(Permissions.View, 'canonicalIdFrom')
@@ -687,6 +718,7 @@ class ZWikiPage(
 
         Constraints for zwiki page ids:
         - it needs to be a legal zope object id
+        - to avoid gross acquisition problems, it needs to avoid certain names
         - to simplify linking, we will require it to be a valid url
         - it should be unique for a given name (ignoring whitespace)
         - we'd like it to be as similar to the name and as simple to read
@@ -694,13 +726,15 @@ class ZWikiPage(
         - we'd like to encourage serendipitous linking between free-form
           and wikiname links & pages
 
-        So this version
-        - discards non-word-separating punctuation (')
-        - converts remaining punctuation to spaces
-        - capitalizes and joins whitespace-separated words into a wikiname
-        - converts any non-zope-and-url-safe characters and _ to _hexvalue
-        - if the above results in an id beginning with _, prepends X
-          (XXX this breaks the uniqueness requirement, better ideas ?)
+        So, we
+        - discard non-word-separating punctuation (')
+        - convert remaining punctuation to spaces
+        - capitalize and join whitespace-separated words into a wikiname
+        - convert any non-zope-and-url-safe characters and _ to _hexvalue
+        - if this results in an id that begins with _ (illegal), prepend X
+        - or if we have a legal id but it's one of the delicate IDS_TO_AVOID
+          (REQUEST, epoz, etc), append X
+          Note these last break the uniqueness property. Better ideas welcome.
 
         performance-sensitive
         """
@@ -725,8 +759,11 @@ class ZWikiPage(
                 safeid = safeid + '_%02x' % ord(c)
 
         # zope ids may not begin with _
-        if len(safeid) > 0 and safeid[0] == '_':
-            safeid = 'X'+safeid
+        if len(safeid) > 0 and safeid[0] == '_': safeid = 'X'+safeid
+
+        # some ids collide with common zope objects and would break things
+        if safeid in IDS_TO_AVOID: safeid = safeid+'X'
+
         return safeid
 
     security.declareProtected(Permissions.View, 'canonicalId')
@@ -766,15 +803,18 @@ class ZWikiPage(
 
         Any keyword arguments will be passed through to the catalog, for
         refining the search, sorting etc. When there is no catalog, only
-        these arguments are supported: id, Title, text, and they do case
-        insensitive partial matching.  With no arguments, all pages in the
-        wiki are returned.
+        these arguments are supported: id, Title, text, isIssue, and they
+        do case insensitive partial matching.  With no arguments, all
+        pages in the wiki are returned.
 
         With a partial catalog, ie a catalog which does not include all
         the metadata Zwiki expects, we'll get the missing fields from the
         zodb and add them to the catalog brains. In this case the
         catalog's caching advantage is lost.
 
+        ensureCompleteMetadata may return None, indicating a stale catalog
+        entry; we filter those out.
+
         Different catalog configurations screw up our title and text
         searches somewhat. For the standard search form, we want: case
         insensitive, partial matching in page names and page text.
@@ -783,18 +823,20 @@ class ZWikiPage(
         if self.hasCatalogIndexesMetadata((['meta_type','path'], [])):
             if self.linkToAllCataloged():
                 # look at all cataloged pages ?
-                return map(lambda x:self.ensureCompleteMetadataIn(x),
-                           self.searchCatalog(meta_type=self.meta_type,
-                                              **kw))
+                return filter(lambda x:x is not None,
+                              map(lambda x:self.ensureCompleteMetadataIn(x),
+                                  self.searchCatalog(meta_type=self.meta_type,
+                                                     **kw)))
             else:
                 # or (usually) just the ones in this folder
                 wikipath = self.wikiPath()
                 def folderpath(s): return s[:s.rfind('/')]
-                return map(lambda x:self.ensureCompleteMetadataIn(x),
-                           filter(lambda x:folderpath(x.getPath())==wikipath,
-                                  self.searchCatalog(meta_type=self.meta_type,
-                                                     path=wikipath,
-                                                     **kw)))
+                return filter(lambda x:x is not None,
+                              map(lambda x:self.ensureCompleteMetadataIn(x),
+                                  filter(lambda x:folderpath(x.getPath())==wikipath,
+                                         self.searchCatalog(meta_type=self.meta_type,
+                                                            path=wikipath,
+                                                            **kw))))
         else:
             results = []
             for p in self.pageObjects(): results.append(self.metadataFor(p))
@@ -821,6 +863,10 @@ class ZWikiPage(
                         results = filter(
                             lambda x:find(x.Title.lower(),value.lower()) != -1,
                             results)
+                    if arg == 'isIssue':
+                        results = filter(
+                            lambda x:self.isIssue(x.Title) == value,
+                            results)
                     #if arg == 'sort_order':
                     #if arg == 'sort_on':
             return results
@@ -836,9 +882,12 @@ class ZWikiPage(
     def pageIds(self):
         """
         Return a list of all page ids in this wiki.
+
+        If there's junk in the catalog, pages could return a page with id
+        None; we guard against that.
         """
         #return self.folder().objectIds(spec=self.meta_type) # more robust ?
-        return map(lambda x:x.id,self.pages())
+        return filter(lambda x:x is not None, map(lambda x:x.id,self.pages()))
 
     security.declareProtected(Permissions.View, 'pageNames')
     def pageNames(self):
@@ -849,42 +898,73 @@ class ZWikiPage(
 
     security.declareProtected(Permissions.View, 'pageIdsStartingWith')
     def pageIdsStartingWith(self,text):
+        """
+        pageIdsStartingWith
+        """
         return filter(lambda x:x[:len(text)]==text,self.pageIds())
 
     security.declareProtected(Permissions.View, 'pageNamesStartingWith')
     def pageNamesStartingWith(self,text):
+        """
+        pageNamesStartingWith
+        """
         return filter(lambda x:x[:len(text)]==text,self.pageNames())
 
     security.declareProtected(Permissions.View, 'firstPageIdStartingWith')
     def firstPageIdStartingWith(self,text):
+        """
+        firstPageIdStartingWith
+        """
         return (self.pageIdsStartingWith(text) or [None])[0]
 
     security.declareProtected(Permissions.View, 'firstPageNameStartingWith')
     def firstPageNameStartingWith(self,text):
+        """
+        firstPageNameStartingWith
+        """
         return (self.pageNamesStartingWith(text) or [None])[0]
 
     security.declareProtected(Permissions.View, 'pageIdsMatching')
     def pageIdsMatching(self,text):
+        """
+        pageIdsMatching
+        """
         text = text.lower()
         return filter(lambda x:x.lower().find(text)!=-1,self.pageIds())
 
     security.declareProtected(Permissions.View, 'pageNamesMatching')
     def pageNamesMatching(self,text):
+        """
+        pageNamesMatching
+        """
         text = text.lower()
         return filter(lambda x:x.lower().find(text)!=-1,self.pageNames())
 
     security.declareProtected(Permissions.View, 'defaultPage')
     def defaultPage(self):
         """
-        Return the page object named in the default_page property, or FrontPage,
-        or the first page object in the folder, or None.
+        Return this wiki's default page (object).
+	
+	That is the page named in the default_page property,
+	or FrontPage,
+        or the first page object in the folder, 
+	or None.
         """
         return (
-            self.pageWithName(getattr(self.folder,'default_page','FrontPage'))
-            or (self.pageObjects()+[None])[0])
+            self.pageWithName(getattr(self.folder(),'default_page','FrontPage'))
+            or (list(self.pageObjects())+[None])[0]) # pageObjects may be a LazyMap
         
     security.declareProtected(Permissions.View, 'defaultPageId')
     def defaultPageId(self):
+        """
+        Return this wiki's default page ID.
+	
+	That is the page named in the default_page property,
+	or FrontPage,
+        or the first page object in the folder, 
+	or None.
+        """
+
         p = self.defaultPage()
         return (p and p.id()) or None
 
@@ -918,7 +998,9 @@ class ZWikiPage(
         else:
             f = self.folder()
             # don't acquire
-            if hasattr(f.aq_base,id) and self.isZwikiPage(f[id]): # poor caching
+            # XXX special case: aq_base adds a REQUEST attribute
+            # ('<Special Object Used to Force Acquisition>')
+            if id in f.objectIds() and self.isZwikiPage(f[id]): # poor caching
                 return f[id]
             elif ignore_case:
                 id = string.lower(id)
@@ -1018,16 +1100,41 @@ class ZWikiPage(
                     results.append(self.metadataFor(p))
             return results
 
+    security.declareProtected(Permissions.View, 'translateHelper')
+    def translateHelper(self,msgid,map=None):
+        """
+        When you want to translate a part of a sentence in a tag attribute,
+        which is computed, you can not use i18n:attribute. and it's difficult
+        to call _("") from the python: Expression.
+
+        dont forget to force i18n extraction with something like
+        
+        <span tal:condition='nothing'>
+            <!-- force i18n extraction -->
+            <span title='Sentence' i18n:attributes='title'></span>            
+        </span>
+        """
+    
+        translate_msg = _(msgid)
+        if map:
+            try:
+                translate_msg = translate_msg % (map)
+            except:
+                return translate_msg
+        return translate_msg
+
     ######################################################################
     # backwards compatibility
 
-    security.declareProtected(Permissions.View, 'stxToHtml')
-    # this must always be available, for the issue properties form
-    def stxToHtml(self,t): return ZwikiStxPageType().renderStxIn(self,t)
     # CMF compatibility
     view = __call__
     SearchableText = EditingSupport.text
-    # old API methods to help keep legacy DTML working
+    # old API methods for skin templates
+    # are security declarations necessary here ?
+    security.declareProtected(Permissions.View, 'quickcomment')
+    quickcomment = slowcomment = EditingSupport.comment
+    security.declareProtected(Permissions.View, 'stxToHtml')
+    def stxToHtml(self,t): return ZwikiStxPageType().renderStxIn(self,t)
     src = EditingSupport.text
     editTimestamp = EditingSupport.timeStamp
     checkEditTimeStamp = EditingSupport.checkEditConflict
@@ -1037,7 +1144,7 @@ class ZWikiPage(
     zwiki_username_or_ip = Utils.usernameFrom
     applyLineEscapesIn = applyWikiLinkLineEscapesIn 
 
-Globals.InitializeClass(ZWikiPage)
+InitializeClass(ZWikiPage)
 
 # rendering helpers
 def thunk_substituter(func, text, allowed):
@@ -1147,7 +1254,7 @@ def sgmlAndDtmlSpansIn(text):
 
 
 # ZMI page creation form
-manage_addZWikiPageForm = DTMLFile('dtml/zwikiPageAdd', globals())
+manage_addZWikiPageForm = DTMLFile('skins/zmi/addwikipageform', globals())
 
 def manage_addZWikiPage(self, id, title='', file='', REQUEST=None,
                         submit=None):
@@ -1172,8 +1279,6 @@ def manage_addZWikiPage(self, id, title='', file='', REQUEST=None,
     p.setText(text or '',REQUEST)
     p.wikiOutline().add(p.pageName()) # update the wiki outline
     p.index_object()
-    if p.usingRegulations():
-        p.setRegulations(REQUEST,new=1)
     if REQUEST is not None:
         try: u=self.DestinationURL()
         except: u=REQUEST['URL1']
