@@ -7,16 +7,17 @@ from Globals import package_home
 from OFS.Folder import Folder
 from OFS.DTMLMethod import DTMLMethod
 from AccessControl import getSecurityManager
-
+from OFS.Image import Image, File
+from OFS.ObjectManager import customImporters
+from Products.PageTemplates.ZopePageTemplate import ZopePageTemplate
+from Products.PythonScripts.PythonScript import PythonScript
 from ZWikiPage import ZWikiPage
 from Defaults import ALLOWED_PAGE_TYPES
-from LocalizerSupport import LocalDTMLFile
-DTMLFile = LocalDTMLFile
-del LocalDTMLFile
+from I18nSupport import DTMLFile
 
 
 # ZMI wiki creation form
-manage_addZWikiWebForm = DTMLFile('dtml/zwikiWebAdd', globals())
+manage_addZWikiWebForm = DTMLFile('skins/zmi/addwikiform', globals())
 
 ######################################################################
 # FUNCTION CATEGORY: wikiweb creation
@@ -46,7 +47,10 @@ def manage_addZWikiWeb(self, new_id, new_title='', wiki_type='zwikidotorg',
             messageDialog('unknown wiki type')
 
         if REQUEST is not None:
-            if enter:
+            folder = getattr(self, new_id)
+            if hasattr(folder, 'setup_%s'%(wiki_type)):
+                REQUEST.RESPONSE.redirect(REQUEST['URL3']+'/'+new_id+'/setup_%s'%(wiki_type))
+            elif enter:
                 # can't see why this doesn't work after addZWikiWebFromFs
                 #REQUEST.RESPONSE.redirect(getattr(self,new_id).absolute_url())
                 REQUEST.RESPONSE.redirect(REQUEST['URL3']+'/'+new_id+'/')
@@ -91,16 +95,29 @@ def addZWikiWebFromFs(self, new_id, title='', wiki_type='zwikidotorg',
     filenames = os.listdir(dir)
     # hmm auto-cataloging is really slowing this down!
     for filename in filenames:
-        if filename[-5:] == '.dtml':
-            text = open(dir + os.sep + filename, 'r').read()
+        if re.match(r'(?:\..*|CVS|_darcs)', filename): continue
+        m = re.search(r'(.+)\.(.+)',filename)
+        id, type = filename, ''
+        if m: id, type = m.groups()
+        text = open(dir + os.sep + filename, 'r').read()
+        if type == 'dtml':
             _addDTMLMethod(ob, filename[:-5], title='', file=text)
+        elif re.match(r'(?:(?:stx|html|latex)(?:dtml)?|txt)', type):
+            _addZWikiPage(ob,id,title='',page_type=type,file=text)
+        elif type == 'pt':
+            ob._setObject(id, ZopePageTemplate(id, text, 'text/html'))
+        elif type == 'py':
+            ob._setObject(id, PythonScript(id))
+            ob._getOb(id).write(text)
+        elif type == 'zexp' or type == 'xml':
+            connection = self.getPhysicalRoot()._p_jar
+            ob._setObject(id, connection.importFile(dir + os.sep + filename, 
+                customImporters=customImporters))
+            #self._getOb(id).manage_changeOwnershipType(explicit=0)
+        elif re.match(r'(?:jpe?g|gif|png)', type):
+            ob._setObject(id, Image(id, '', text))
         else:
-            m = re.search(r'(.+)\.(.+)',filename)
-            if m:
-                text = open(dir + os.sep + filename, 'r').read()
-                name, type = m.group(1), m.group(2)
-                _addZWikiPage(ob,name,title='',page_type=type,file=text)
-        # files without a suffix are ignored
+            ob._setObject(id, File(id, '', text))
 
 def _addDTMLMethod(self, id, title='', file=''):
     id=str(id)
@@ -119,10 +136,11 @@ def _addZWikiPage(self, id, title='',
 
     # choose page type based on file suffix
     # must match ids in PageTypes.py
-    if page_type == 'stxdtml': page_type = 'msgstxprelinkdtmlfitissuehtml'
-    elif page_type == 'stx': page_type = 'msgstxprelinkdtmlfitissuehtml'
-    elif page_type == 'htmldtml': page_type = 'dtmlhtml'
-    elif page_type == 'html': page_type = 'dtmlhtml'
+    from ZWikiPage import PAGE_TYPES
+    if page_type == 'stxdtml': page_type = PAGE_TYPES['stx']
+    elif page_type == 'stx': page_type = PAGE_TYPES['stx']
+    elif page_type == 'htmldtml': page_type = PAGE_TYPES['html']
+    elif page_type == 'html': page_type = PAGE_TYPES['html']
     
     # parse optional parents list
     m = re.match(r'(?si)(^#parents:(.*?)\n)?(.*)',file)
@@ -179,6 +197,8 @@ def listFsWikis(self):
         # developers may have content/CVS.. assume wiki templates
         # will never be called that:
         if 'CVS' in list: list.remove('CVS')
+        # likewise for Subversion
+        if '.svn' in list: list.remove('.svn')
         if 'tracker' in list: list.remove('tracker') #XXX temp
         return list
     except OSError:
