@@ -10,7 +10,7 @@ class ZWikiPageTests(ZopeTestCase.ZopeTestCase):
         zwikiAfterSetUp(self)
 
     def test_excerptAt(self):
-        self.page.edit(text='This is a test of the<br>\n excerptAt method,')
+        self.page.edit(text='This is a test of the<br />\n excerptAt method,')
         self.assertEquals(self.page.excerptAt('excerptat',size=10,highlight=0),
                           '\n excerptAt ')
         #self.assertEquals(self.page.excerptAt('this*',size=21,highlight=1),
@@ -21,9 +21,9 @@ class ZWikiPageTests(ZopeTestCase.ZopeTestCase):
         self.assertEquals(self.page.excerptAt('this*',size=21,highlight=1),
                           '<span class="hit" style="background-color:yellow;font-weight:bold;">This</span> is a tes')
         self.assertEquals(self.page.excerptAt('br',size=4),
-                          'e&lt;<span class="hit" style="background-color:yellow;font-weight:bold;">br</span>&gt;\n')
-        self.assertEquals(self.page.excerptAt('<br>',size=4,highlight=0),
-                          'e&lt;br&gt;\n')
+                          'e&lt;<span class="hit" style="background-color:yellow;font-weight:bold;">br</span> /')
+        self.assertEquals(self.page.excerptAt('<br />',size=4,highlight=0),
+                          '&lt;br /&gt;')
         self.assertEquals(self.page.excerptAt('nomatch'),'')
         self.assertEquals(self.page.excerptAt(''),'')
 
@@ -149,6 +149,11 @@ class ZWikiPageTests(ZopeTestCase.ZopeTestCase):
             'WikiName, [freeform name], [[double brackets]]'),
             'WikiName, [freeform name], [[double brackets]]')
 
+    def test_formatWikiname(self):
+        self.assertEquals(self.p.formatWikiname('CamelCase'),'CamelCase')
+        self.p.folder().spaced_wikinames = 1
+        self.assertEquals(self.p.formatWikiname('CamelCase'),'Camel Case')
+
     def test_renderLink(self):
         self.assertEquals(
             self.p.renderLink('[unbalanced (]')[-53:],
@@ -156,7 +161,9 @@ class ZWikiPageTests(ZopeTestCase.ZopeTestCase):
         self.assertEquals(
             self.p.renderLink('http://some.url'),
             '<a href="http://some.url">http://some.url</a>')
-
+        #self.p.folder().spaced_wikinames = 1
+        #self.assertEquals(self.p.renderLink('CamelCase')[:10],'Camel Case')
+        
     def test_renderLinksIn(self):
         self.assertEquals(self.p.renderLinksIn('nolink'),'nolink')
         self.assertEquals(self.p.renderLinksIn('http://a.b.c/d'),
@@ -168,11 +175,11 @@ class ZWikiPageTests(ZopeTestCase.ZopeTestCase):
                           '<a href="http://nohost/test_folder_1_/wiki/TestPage" title="" style="background-color:;">TestPage</a>')
 #                          '<a href="/test_folder_1_/wiki/TestPage" title="" style="background-color:;">TestPage</a>')
         self.assertEquals(self.p.renderLinksIn('NewTestPage'),
-                          'NewTestPage<a class="new" href="http://nohost/test_folder_1_/wiki/TestPage/editform?page=NewTestPage" title="create this page">?</a>')
+                          'NewTestPage<a class="new" href="http://nohost/test_folder_1_/wiki/TestPage/createform?page=NewTestPage" title="create this page">?</a>')
 #                          'NewTestPage<a class="new" href="/test_folder_1_/wiki/TestPage/editform?page=NewTestPage" title="create this page">?</a>')
         self.assertEquals(self.p.renderLinksIn('!TestPage'),'TestPage')
         self.assertEquals(self.p.renderLinksIn('[newpage]'),
-                          '[newpage]<a class="new" href="http://nohost/test_folder_1_/wiki/TestPage/editform?page=newpage" title="create this page">?</a>')
+                          '[newpage]<a class="new" href="http://nohost/test_folder_1_/wiki/TestPage/createform?page=newpage" title="create this page">?</a>')
 #                          '[newpage]<a class="new" href="/test_folder_1_/wiki/TestPage/editform?page=newpage" title="create this page">?</a>')
         # a problem with escaping remote wiki links was reported
         self.p.edit(text='RemoteWikiURL: URL/')
@@ -181,11 +188,11 @@ class ZWikiPageTests(ZopeTestCase.ZopeTestCase):
         self.assertEquals(self.p.renderLinksIn('!TestPage:REMOTEPAGE'),
                           'TestPage:REMOTEPAGE')
         self.assertEquals(self.p.renderLinksIn('[ ]'),
-                          '[ ]<a class="new" href="http://nohost/test_folder_1_/wiki/TestPage/editform?page=%20" title="create this page">?</a>')
+                          '[ ]<a class="new" href="http://nohost/test_folder_1_/wiki/TestPage/createform?page=%20" title="create this page">?</a>')
 #                          '[ ]<a class="new" href="/test_folder_1_/wiki/TestPage/editform?page=%20" title="create this page">?</a>')
         # do display the brackets prior to page creation
         self.assertEquals(self.p.renderLinksIn('[newpage]'),
-                          '[newpage]<a class="new" href="http://nohost/test_folder_1_/wiki/TestPage/editform?page=newpage" title="create this page">?</a>')
+                          '[newpage]<a class="new" href="http://nohost/test_folder_1_/wiki/TestPage/createform?page=newpage" title="create this page">?</a>')
 #                          '[newpage]<a class="new" href="/test_folder_1_/wiki/TestPage/editform?page=newpage" title="create this page">?</a>')
         # don't link wikinames inside <a href...>...</a>
         self.assertEquals(self.p.renderLinksIn('<a href>WikiName</a>'),
@@ -193,7 +200,7 @@ class ZWikiPageTests(ZopeTestCase.ZopeTestCase):
         # do link wikinames after <a name...> with no closing </a>
         self.assertEquals(self.p.renderLinksIn('<a name>WikiName'),
 #                          '<a name>WikiName<a class="new" href="/test_folder_1_/wiki/TestPage/editform?page=WikiName" title="create this page">?</a>')
-                          '<a name>WikiName<a class="new" href="http://nohost/test_folder_1_/wiki/TestPage/editform?page=WikiName" title="create this page">?</a>')
+                          '<a name>WikiName<a class="new" href="http://nohost/test_folder_1_/wiki/TestPage/createform?page=WikiName" title="create this page">?</a>')
 
 
 
